
# Slot: model_activity_enabled_by_rollup

The rollup of `model_activity_enabled_by_closure` to a GO subset or slim.

URI: [gocam:queryIndex__model_activity_enabled_by_rollup](https://w3id.org/gocam/queryIndex__model_activity_enabled_by_rollup)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [TermObject](TermObject.md)

## Parents


## Children


## Used by

 * [QueryIndex](QueryIndex.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | added for completion but may not be useful in practice |
